#
# spec file for package python-pytest-shutil
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-shutil
Version:        1.8.0
Release:        2.1
Summary:        A goodie-bag of unix shell and environment tools for pytest
License:        MIT
URL:            https://github.com/man-group/pytest-plugins
Source:         https://files.pythonhosted.org/packages/source/p/pytest-shutil/pytest-shutil-%{version}.tar.gz
BuildRequires:  %{python_module execnet}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module termcolor}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-execnet
Requires:       python-pytest
Requires:       python-six
Requires:       python-termcolor
BuildArch:      noarch

%python_subpackages

%description
This library is a goodie-bag of Unix shell and environment management
tools for automated tests.

%prep
%autosetup -p2 -n pytest-shutil-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Disable test_pretty_formatter test that fails in osc build but it works when
# run manually. It should be something related to the shell and termcolor
%pytest -k "not test_pretty_formatter"

%files %{python_files}
%doc README.md CHANGES.md
%license LICENSE
%{python_sitelib}/pytest_shutil
%{python_sitelib}/pytest_shutil-%{version}.dist-info

%changelog
* Mon Nov  4 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed dep python-setuptools-git
* Tue Oct 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.8.0:
  * Drop support for Python 2 and <3.6, removing compatibility code.
  * Use stdlib unittest.mock instead of mock package.
  * Removed usage of path.py and path in favour of pathlib.
  * Removed contextlib2 requirement.
  * Fixed forcing color through termcolor.
- Drop patches, included upstream:
  * pytest-fixtures-pr171-remove-mock.patch
  * stop-using-imp.patch
* Wed Jan 24 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch stop-using-imp.patch:
  * Use importlib and not imp.
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Dec  5 2022 Daniel Garcia <daniel.garcia@suse.com>
- Disable test_pretty_formatter test that fails in osc build but it works when
  run manually.
* Thu Apr 21 2022 Ben Greiner <code@bnavigator.de>
- Fixup fallout from SUSE's crusade against mock in the
  pytest-fixtures family
  * Replace remove-mock.patch with
    pytest-fixtures-pr171-remove-mock.patch
  * gh#man-group/pytest-plugins#171
  * Update build and runtime requirements
* Wed Mar 23 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-mock.patch:
  * Do not use external mock.
* Fri Mar 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Build without python2 present
* Sat Dec 28 2019 Ondřej Súkup <mimi.vx@gmail.com>
- fix python-path/python-path.py requires
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * Support pytest 4
* Fri Mar 22 2019 John Vandenberg <jayvdb@gmail.com>
- Remove dependency on contextlib2 on Python 3
* Wed Feb 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, neded by pytest-virtualenv
